@@ -2,7 +2,7 @@
 # Copyright © 2019 Midgard
 # License: GPLv3+
 
-from datetime import datetime
+from datetime import datetime, date
 from .messages import t
 import re
 
@@ -115,7 +115,13 @@ def print_liveboard(liveboard, tele=None):
 		train=t("train"), destination=t("destination"), platform=t("platform"),
 		departure=t("departure")
 	))
+
+	prev_date = date.today()
 	for line in liveboard["departures"]["departure"]:
+		dep_time = datetime.fromtimestamp(int(line["time"]))
+		if dep_time.date() != prev_date:
+			print(" " * 12 + format_date(dep_time))
+			prev_date = dep_time.date()
 		print_liveboard_item(line)
 
 
@@ -213,6 +219,13 @@ def max_delay_str_length(connection_item):
 	)
 
 
+def format_date(d):
+	return "\x1b[1m{:%Y-%m-%d} {}\x1b[0m".format(
+		d,
+		t("day_of_week_{}".format(d.weekday()))
+	)
+
+
 def print_connections(connections):
 	max_duration_len = max(max((
 		len(format_duration(item["duration"]))
@@ -232,7 +245,13 @@ def print_connections(connections):
 		train=t("train"), towards=t("towards")
 	))
 
+	prev_date = date.today()
 	for line in connections["connection"]:
+		dep_time = datetime.fromtimestamp(int(line["departure"]["time"]))
+		if dep_time.date() != prev_date:
+			print("\n" + format_date(dep_time))
+			prev_date = dep_time.date()
+
 		print_connection_item(line, max_duration_len, max_delay_len)
 
 
